All platforms.

flathead.logic

This namespace contains higher order logic functions. The purpose is to augment clojure core logic to ramda level.

This namespace contains higher order logic functions.
The purpose is to augment clojure core logic to ramda level.
raw docstring

if*clj/s

(if* predicate then-fn)
(if* predicate then-fn else-fn)

Higher order ramda style if-function.

Higher order ramda style if-function.
sourceraw docstring

unless*clj/s

(unless* predicate then-fn)

Higher order ramda style unless-function. Same as (when (complement predicate) then-fn)

Higher order ramda style unless-function. Same as (when (complement predicate) then-fn)
sourceraw docstring

when*clj/s

(when* predicate then-fn)

Higher order ramda style when-function. This is convenient with walk/postwalk

Higher order ramda style when-function. This is convenient with walk/postwalk
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries