flathead.plain


->propertiesclj

(->properties object)
source

flat->treeclj/s

(flat->tree row)
(flat->tree key->path row)

Transforms a flat associative array (map) to a nested structure so that all values are associated to a new nested or existing map using a specific key path, which is generated from the current key of the value using key->path function.

This is an inverse of the deep/flat->tree function.

A default implementation assumes that the flat keys are directly the paths.

Transforms a flat associative array (map) to a nested structure so that all values
 are associated to a new nested or existing map using a specific key path, which is generated from
 the current key of the value using key->path function.

This is an inverse of the deep/flat->tree function.

 A default implementation assumes that the flat keys are directly the paths.
sourceraw docstring

map-keysclj/s

(map-keys f m)
source

map-valuesclj/s

(map-values f m)
source

sequence->mapclj/s

(sequence->map sequence)
source

cljdoc builds & hosts documentation for Clojure/Script libraries