This namespace contains higher order logic functions. The purpose is to augment clojure core logic to ramda level.
This namespace contains higher order logic functions. The purpose is to augment clojure core logic to ramda level.
(if* predicate then-fn)(if* predicate then-fn else-fn)Higher order ramda style if-function.
Higher order ramda style if-function.
(unless* predicate then-fn)Higher order ramda style unless-function. Same as (when (complement predicate) then-fn)
Higher order ramda style unless-function. Same as (when (complement predicate) then-fn)
(when* predicate then-fn)Higher order ramda style when-function. This is convenient with walk/postwalk
Higher order ramda style when-function. This is convenient with walk/postwalk
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |