(flat->tree row)(flat->tree key->path row)Transforms a flat associative array (map) to a nested structure so that all values are associated to a new nested or existing map using a specific key path, which is generated from the current key of the value using key->path function.
This is an inverse of the deep/flat->tree function.
A default implementation assumes that the flat keys are directly the paths.
Transforms a flat associative array (map) to a nested structure so that all values are associated to a new nested or existing map using a specific key path, which is generated from the current key of the value using key->path function. This is an inverse of the deep/flat->tree function. A default implementation assumes that the flat keys are directly the paths.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |